@@ -7,13 +7,18 @@
 
 #include <QAbstractListModel>
 #include <QObject>
-#include <kunitconversion/unit.h>
 #include <kunitconversion/converter.h>
+#include <kunitconversion/unit.h>
+#include <qobject.h>
+#include <qqmlintegration.h>
 #include <tuple>
 
 class UnitModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
+
     Q_PROPERTY(QStringList typeList READ typeList NOTIFY typeListChanged)
     Q_PROPERTY(QString result READ result NOTIFY resultChanged)
     Q_PROPERTY(QString value READ value WRITE setValue NOTIFY valueChanged)
@@ -21,11 +26,9 @@ class UnitModel : public QAbstractListModel
     Q_PROPERTY(int fromUnitIndex READ fromUnitIndex WRITE setFromUnitIndex NOTIFY unitIndexChanged)
     Q_PROPERTY(int toUnitIndex READ toUnitIndex WRITE setToUnitIndex NOTIFY unitIndexChanged)
 public:
-    static UnitModel *inst()
-    {
-        static UnitModel singleton;
-        return &singleton;
-    }
+    explicit UnitModel(QObject *parent = nullptr);
+    ~UnitModel();
+
     int rowCount(const QModelIndex &parent) const override;
     QVariant data(const QModelIndex &index, int role) const override;
     QHash<int, QByteArray> roleNames() const override;
@@ -57,7 +60,7 @@ public:
     void setCurrentIndex(int i);
     void setFromUnitIndex(int i);
     void setToUnitIndex(int i);
-    
+
 Q_SIGNALS:
     void typeListChanged();
     void valueChanged();
@@ -69,7 +72,6 @@ private Q_SLOTS:
     void calculateResult();
 
 private:
-    UnitModel();
     int m_currentIndex = 0;
     int m_fromUnitIndex = 0;
     int m_toUnitIndex = 1;
